@@ -2,7 +2,12 @@ test_that("framework-eda.R works on KOOTENAI RIVER (08NH021) with no splits", {
 
 	df <- data_local("CAN-08NH021.csv")
 
-	results <- framework_eda(df$max, df$year)
+	results <- framework_eda(
+		df$max,
+		df$year,
+		generate_report = FALSE
+	)
+
 	expect_true(is.list(results))
 	expect_equal(length(results$submodule_results), 2)
 
@@ -17,7 +22,13 @@ test_that("framework-eda.R works on KOOTENAI RIVER (08NH021) with splits", {
 
 	df <- data_local("CAN-08NH021.csv")
 
-	results <- framework_eda(df$max, df$year, ns_splits = 1972)
+	results <- framework_eda(
+		df$max,
+		df$year,
+		ns_splits = 1972,
+		generate_report = FALSE
+	)
+
 	expect_true(is.list(results))
 	expect_equal(length(results$submodule_results), 3)
 
