@@ -1,7 +1,12 @@
 test_that("framework-full works on KOOTENAI RIVER (08NH021) with no splits/structures", {
 	df <- data_local("CAN-08NH021.csv")
 
-	results <- framework_full(df$max, df$year)
+	results <- framework_full(
+		df$max,
+		df$year,
+		generate_report = FALSE
+	)
+
 	expect_true(is.list(results))
 	expect_equal(length(results$submodule_results), 6)
 
@@ -18,10 +23,16 @@ test_that("framework-full works on KOOTENAI RIVER (08NH021) with no splits/struc
 })
 
 test_that("framework-full works on KOOTENAI RIVER (08NH021) with splits/structures", {
-
 	df <- data_local("CAN-08NH021.csv")
 
-	results <- framework_full(df$max, df$year, 1972, list(S10, S10))
+	results <- framework_full(
+		df$max,
+		df$year,
+		1972,
+		list(S10, S10),
+		generate_report = FALSE
+	)
+
 	expect_true(is.list(results))
 	expect_equal(length(results$submodule_results), 11)
 
